====================================
Client interface for Scrapinghub API
====================================

.. image:: https://secure.travis-ci.org/scrapinghub/python-scrapinghub.png?branch=master
   :target: http://travis-ci.org/scrapinghub/python-scrapinghub

The ``scrapinghub`` is a Python library for communicating with the `Scrapinghub API`_.


Requirements
============

* Python 2.7 or above


Installation
============

The quick way::

    pip install scrapinghub

You can also install the library with MessagePack support, it provides better
response time and improved bandwidth usage::

    pip install scrapinghub[msgpack]


Documentation
-------------

Documentation is `available online`_ via Read the Docs or in the ``docs`` directory.


.. _Scrapinghub API: http://doc.scrapinghub.com/api.html
.. _available online: https://python-scrapinghub.readthedocs.io/
